@@ -1,5 +1,5 @@
 /**
- * Copyright (C) 2006-2017 Henning Norén
+ * Copyright (C) 2006-2019 Henning Norén
  * 
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -346,7 +346,7 @@ parseRegularString(FILE *file) {
     if((len > 1) && ((len%2) == 0))
       ret = parseHexString(buf,len);
   }
-return ret;
+  return ret;
 }
 
 static int
@@ -408,8 +408,7 @@ findTrailerDict(FILE *file, EncData *e) {
 	      ch = getc(file);
 
 	    if(str) {
-	      if(str->content)
-		free(str->content);
+	      free(str->content);
 	      free(str);
 	    }
 	      
@@ -446,8 +445,7 @@ findTrailerDict(FILE *file, EncData *e) {
   /**  printf("finished searching\n");*/
   
   if(str) {
-    if(str->content)
-      	free(str->content);
+    free(str->content);
     free(str);
   }
   
@@ -554,8 +552,7 @@ findTrailer(FILE *file, EncData *e) {
   /**  printf("finished searching\n");*/
 
   if(str) {
-    if(str->content)
-      	free(str->content);
+    free(str->content);
     free(str);
   }
 
@@ -733,7 +730,6 @@ parseEncrypObject(FILE *file, EncData *e) {
     }
     ch = parseWhiteSpace(file);
   }
-    printf("\n");
 
   if(!fe)
     e->encryptMetaData = true;
@@ -773,7 +769,20 @@ parseEncrypObject(FILE *file, EncData *e) {
 
   if(ff && strcmp(e->s_handler,"Standard") != 0)
     return true;
-
+  
+  /**
+  if(ff)
+    printf("Found Filter\n");
+  if(fo)
+    printf("Found Owner string\n");
+  if(fp)
+    printf("Found Permission\n");
+  if(fr)
+    printf("Found Revision\n");
+  if(fu)
+    printf("Found User String\n");
+  */
+ 
   return ff & fo && fp && fr && fu;
 }
 
@@ -781,11 +790,13 @@ parseEncrypObject(FILE *file, EncData *e) {
     This is not a really definitive search.
     Should be replaced with something better
 */
+
 static bool
 findEncryptObject(FILE *file, const int e_pos, EncData *e) {
   int ch;
 
   /** only find the encrypt object if e_pos > -1 */
+  
   if(e_pos < 0)
     return false;
 
@@ -805,6 +816,29 @@ findEncryptObject(FILE *file, const int e_pos, EncData *e) {
     }
     ch = getc(file);
   }
+
+  /** If this fails, do relaxed check to see if we might find it without
+      a EndOfLine character before the object */
+  rewind(file);
+  ch = getc(file);
+  while(ch != EOF) {
+    if(ch >= '0' && ch <= '9') {
+      ungetc(ch,file);
+      if(parseInt(file) == e_pos) {
+	ch = parseWhiteSpace(file);
+	if(ch >= '0' && ch <= '9') {
+	  ch = parseWhiteSpace(file);
+	  if(ch == 'o' && getc(file) == 'b' && getc(file) == 'j' &&
+	     parseWhiteSpaceOrComment(file) == '<' && getc(file) == '<') {
+	    return parseEncrypObject(file, e);
+	  }
+	}
+      }
+    }
+    ch = getc(file);
+  }
+
+  /** give up */
   return false;
 }
 
