@@ -1,5 +1,5 @@
 /**
- * Copyright (C) 2006-2014 Henning Norén
+ * Copyright (C) 2006-2017 Henning Norén
  * 
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -17,7 +17,6 @@
  * USA.
  */
 #include <string.h>
-#include <assert.h>
 #include "rc4.h"
 
 #define likely(x)       __builtin_expect((x),1)
@@ -229,8 +228,8 @@ rc4Decrypt(const uint8_t *key, const uint8_t *bs,
 /** sets which function the wrapper should call */
 bool
 setrc4DecryptMethod(const unsigned int length) {
-  assert(length < 256);
-  assert((length % 8) == 0);
+  if(length > 255 || length < 40 || length % 8 != 0)
+    return false;
 
   if(length == 128) {
     rc4d = &rc4Decrypt128b;
